@@ -11,7 +11,7 @@ from qdk.dagster_types import DataFrameType, ModelType, SeriesType
 from sklearn.base import BaseEstimator
 
 
-class TrainingComponent(BaseComponent):
+class BaseTrainer(BaseComponent):
     compute_function = "train"
     tags = {
         "kind": "training",
